def AutoClean():
  print('This project has just started!')
  print('It is actively being worked on...')
  print('As of right now I have only published this project to reserve the name')
  print('Sorry for the inconvience')

if __name__ == '__main__':
  AutoClean()
